//**********************************************************************
//
// Sample Java EIF Adapter
//
//***********************************************************************
package samples.adapters.java;

import com.tivoli.tec.event_delivery.TECAgent;
import com.tivoli.tec.event_delivery.TECEvent;
import com.tivoli.tec.event_delivery.EDException;

import java.io.Reader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.FileReader;
import java.io.InputStreamReader;
import java.util.StringTokenizer;

public class SampleAdapter
{
   private static void usage()
   {
      System.out.println("\nNote: Be sure to put evd.jar and log.jar in your CLASSPATH.\n");
      System.out.println("Usage: java samples.adapters.java.javaadpt -f config_file\n");
      System.out.println("Event syntax is: key=val;key=val; CLASS SOURCE\n");
   }

   public static void main(String[] args)
   {
      TECAgent agent = null;
      int rc = 0;
      int strc = 0;
      String cfgFile = null;
      Reader cfgIn = null;
      String nextline = null;
      String classsource;
      String allslots;
      String slot;
      String evclass;
      String evsource;
      String key;
      String val;
      int keyindex;
      int lastsemi;

      if ((args.length != 2) ||
          (!args[0].equals("-f")))
      {
         usage();
         System.exit(1);
      }
      else
      {
         cfgFile = args[1];
         System.out.println("cfgFile: " + cfgFile + "\n");
         File f = new File(cfgFile);
         if (!f.exists())
         {
            System.err.println("File: " + cfgFile + " does not exist.\n");
            System.exit(1);
         }

         if (!f.canRead())
         {
            System.err.println("Error reading file: " + cfgFile + "\n");
            System.exit(1);
         }

         try
         {
            cfgIn = new FileReader(cfgFile);
         }
         catch (FileNotFoundException e)
         {
            System.err.println(e);
            System.exit(1);
         }
      }
      try
      {
         agent = new TECAgent(cfgIn, TECAgent.SENDER_MODE, false);
      }
      catch (EDException e)
      {
         System.err.println(e);
         System.exit(1);
      }

      BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
      System.out.println("Now ready to enter events: key=val;key=val; CLASS SOURCE\n");
      try
      {
         nextline = br.readLine();
      }
      catch (IOException ex)
      {
         System.err.println(ex);
         System.exit(1);
      }

      while (nextline.length() != 0)
      {
         strc = 0;
         TECEvent event = new TECEvent();
         lastsemi = nextline.lastIndexOf(";");

         if (lastsemi == -1)
         {
            classsource = nextline;
            allslots = "";
         }
         else
         {
            classsource = nextline.substring(lastsemi + 1);
            allslots = nextline.substring(0, lastsemi);
         }

         // The following line works even if there are no semicolons
         StringTokenizer cl_sr = new StringTokenizer(classsource);
         if (cl_sr.countTokens() != 2)
         {
            strc = 1;
            usage();
         }
         else
         {
            evclass = cl_sr.nextToken();
            event.setClassName(evclass);
            evsource = cl_sr.nextToken();
            event.setSlot("source", evsource);
         }

         StringTokenizer stslots = new StringTokenizer(allslots, ";");

         while (stslots.hasMoreTokens())
         {
            slot = stslots.nextToken();
            keyindex = slot.indexOf("=");
            if ((keyindex == -1) ||
                (keyindex == 0) ||
                (keyindex == (slot.length() - 1)))
            {
               strc = 2;
               usage();
            }
            else
            {
               key = slot.substring(0, keyindex);
               val = slot.substring(keyindex + 1);
               event.setSlot(key, val);
            }
         }

         if (strc == 0)
         {
            rc = agent.sendEvent(event.toString(true));
            if (rc == -1)
            {
                System.out.println("sendEvent failed, rc = " + rc);
            }
         }
         try
         {
            nextline = br.readLine();
         }
         catch (IOException ex)
         {
            System.err.println(ex);
            System.exit(1);
         }
      }
      agent.disconnect(0);
      System.out.println("Goodbye.\n");
      System.exit(rc != TECAgent.SEND_FAILURE ? 0 : 1);
   }
}
