/*******************************************************************
 * Sample "adapter" for Unix or Windows.
 * Link with the appropriate libraries to builda TME managed
 * node version, TME endpoint version, or non-TME (Socket) version.
 *******************************************************************/

#include <sys/stat.h>
#include <stdio.h>
#include "tec_eeif.h"


static char s [2048];


void print_usage_and_exit (char **argv)
{
    fprintf(stderr, "Usage: ceeifadpt -f cfgfile \n");
    fprintf(stderr, "When prompted, enter an event such as: EVENT;source=TEC;msg=ceeifadpt;\n");
    fprintf(stderr, "You may continue to enter events. This program will end when you enter\n");
    fprintf(stderr, "a null line.\n");
    
    exit(1);
}
int main(int argc, char *argv [])
{
    int rc;
    char *result;
    extern int optind;
    extern char *optarg;
    char cfg_file_name [256];
    char *cfg_file = NULL;
    tec_handle_t th;
    extern int tec_errno;
    struct stat sbuf;

#ifdef WIN32
    WSADATA wsaData;
    if ((rc = WSAStartup(MAKEWORD(1,1), &wsaData)) != 0)
    {
        printf("error %dstarting winsock.dll \n", rc);
        exit(1);
    }
    else
    {
        printf("Winsock initialized successfully...\n");
    }
#endif
    if (argc != 3) 
    {
        print_usage_and_exit(argv);
    }
    else
    {
        /* Parm specifies the location of the adapter configuration file */
        strcpy(cfg_file_name, argv[2]);
        /* Make sure the configuration file exists */
        
        if (stat(cfg_file_name, &sbuf) != 0)
        {
            printf("Cannot find the configuration file: %s \n", cfg_file_name);
            print_usage_and_exit (argv);
        }
        cfg_file = cfg_file_name;
    }
    if (cfg_file == NULL)
    {
        print_usage_and_exit (argv);
    }
    rc = tec_agent_init(cfg_file);
    if (rc != 0)
    {
        fprintf(stderr, "tec_agent_init failed, errno=%d \n", tec_errno);
        exit(1);
    }
    th = tec_create_handle(NULL, 0, 0, use_default);
    if (th == NULL)
    {
        fprintf(stderr, "tec_create_handle failed, errno=%d \n", tec_errno);
        exit(1);
    }
    printf("\nNow enter an event such as: EVENT;source=TEC;msg=ceeifadpt;\n");

    while (1)
    {
        /* Now wait on user input. eadlines from stdin andsendthe */
        /* input as an event. */
        /* Note: The gets function will block TME threadexecution. */
        /* This is only a problem when linking with the TME libraries. */
        /* The workaroundis to use the SELECT function call to wait */
        /* on input from the keyboard. */
        
        if ((result = gets(s)) == NULL)
        {
            if (ferror(stdin))
            {
                printf("gets Error\n");
                clearerr(stdin);
            }
            printf("Lets try gets again\n");
        }
        else
        {
            if (strlen(s) == 0)
            {
                printf("Goodbye.\n");
                break;
            }
            
            /* tec_put_event will sendthe event to the server specifiedby */
            /* the configuration file. tec_put_event will addthe "END" and*/
            /* other data necessary to complete the event. */
            rc = tec_put_event(th, s);
            if (rc == -1)
            {
                printf("tec_put_event failed, errno=%d \n", tec_errno);
            }
        }
    }
    
    printf("Calling tec_destroy_handle\n");
    /*eof-close the connection andexit */
    tec_destroy_handle(th);
    exit(0);
}
